package com.dweb.atmosphere.grizzly;

import static org.atmosphere.cpr.ApplicationConfig.MAX_INACTIVE;

import java.io.IOException;

import org.atmosphere.config.service.Disconnect;
import org.atmosphere.config.service.Get;
import org.atmosphere.config.service.ManagedService;
import org.atmosphere.config.service.Ready;
import org.atmosphere.cpr.AtmosphereResource;
import org.atmosphere.cpr.AtmosphereResourceEvent;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;


/**
 * Simple annotated class that demonstrate the power of Atmosphere. This class
 * supports all transports, support message length garantee, heart beat, message
 * cache thanks to the @ManagedService
 * 
 * More information available at: http://goo.gl/uFE5Q9
 */

@Config
@ManagedService(path = "/chat", atmosphereConfig = MAX_INACTIVE + "=120000")
public class Chat {

	private final Logger logger = LoggerFactory.getLogger(Chat.class);

	/**
	 * Invoked via Http Get requests
	 * 
	 * @param res
	 */
	@Get
	public void get(final AtmosphereResource res) {
		res.getResponse().write("Http Get Response");
	}

	/**
	 * Invoked when the connection as been fully established and suspended, e.g
	 * ready for receiving messages.
	 * 
	 * @param r
	 */
	@Ready
	public void onReady(final AtmosphereResource res) {
		logger.debug("Browser {} connected.", res.uuid());
	}

	/**
	 * Invoked when the client disconnect or when an unexpected closing of the
	 * underlying connection happens.
	 * 
	 * @param event
	 */
	@Disconnect
	public void onDisconnect(final AtmosphereResourceEvent event) {
		if (event.isCancelled()) {
			logger.info("Browser {} unexpectedly disconnected", event
					.getResource().uuid());
		} else if (event.isClosedByClient()) {
			logger.info("Browser {} closed the connection", event.getResource()
					.uuid());
		}
	}

	/**
     * Simple annotated class that demonstrate how {@link org.atmosphere.config.managed.Encoder} and {@link org.atmosphere.config.managed.Decoder
     * can be used.
     *
     * @param message an instance of {@link Message}
     * @return
     * @throws IOException
     */
	@org.atmosphere.config.service.Message(encoders = { JacksonEncoder.class }, decoders = { JacksonDecoder.class })
	public Message onMessage(Message message) throws IOException {
		logger.info("{} just send {}", message.getAuthor(),
				message.getMessage());
		return message;
	}

}