package com.dweb.atmosphere.grizzly;

import java.io.IOException;

import org.atmosphere.cpr.AtmosphereServlet;
import org.glassfish.grizzly.http.server.HttpServer;
import org.glassfish.grizzly.http.server.NetworkListener;
import org.glassfish.grizzly.http.server.StaticHttpHandler;
import org.glassfish.grizzly.servlet.ServletRegistration;
import org.glassfish.grizzly.servlet.WebappContext;
import org.glassfish.grizzly.websockets.WebSocketAddOn;


/**
 * Developed to test Atmosphere 2.1.3 integrated with Grizzly 2.3.11. This
 * code is based on this atmosphere sample: http://goo.gl/VcMVUB
 * 
 * Detected and reported some issue related to Grizzly & Atmosphere:
 * http://goo.gl/siwq1O
 * 
 * To run the test you can use one of these clients:
 * 
 * -. http://localhost:8080
 * -. http://www.websocket.org/echo.html
 * -. Chrome Javascript console: new WebSocket('ws://localhost:8181/chat');
 * 
 * @author mnateras
 *
 */

public class Main {
	
	private static final int HTTP_PORT = 8080;
	private static final int WS_PORT = 8181;

	public static void main(String[] args) throws IOException {

		final HttpServer server = HttpServer.createSimpleServer(".", WS_PORT);

		final WebappContext ctx = new WebappContext("ctx", "/");

		// enable web socket support
		final WebSocketAddOn addon = new WebSocketAddOn();

		for (NetworkListener listener : server.getListeners()) {
			listener.registerAddOn(addon);
		}

		// add atmosphere servlet support
		final AtmosphereServlet atmosphereServlet = new AtmosphereServlet();

		final ServletRegistration atmosphereServletRegistration = ctx
				.addServlet("AtmosphereServlet", atmosphereServlet);

		atmosphereServletRegistration.setInitParameter(
				"org.atmosphere.websocket.messageContentType",
				"application/json");
		atmosphereServletRegistration.addMapping("/chat/*");
		atmosphereServletRegistration.setLoadOnStartup(1);
		
		// To avoid problems, I use a new server to serve static assets
		final HttpServer staticServer = HttpServer
				.createSimpleServer(".", HTTP_PORT);
		final StaticHttpHandler staticHttpHandler = new StaticHttpHandler(
				"src/main/resources");
		staticServer.getServerConfiguration().addHttpHandler(staticHttpHandler,
				"/");

		// deploy
		ctx.deploy(server);

		try {
			server.start();
			staticServer.start();
			System.out.println("Press enter to stop the server...");
			System.in.read();
		} finally {
			staticServer.shutdown();
			server.shutdownNow();
		}

	}

}